pub struct PredicateStats {
pub name: String,
pub count: usize,
pub unique_subjects: usize,
pub unique_objects: usize,
pub is_functional: bool,
pub is_inverse_functional: bool,
}Expand description
Per-predicate statistics.
Fields
name: StringPredicate name (IRI)
count: usizeNumber of triples using this predicate
unique_subjects: usizeNumber of unique subjects for this predicate
unique_objects: usizeNumber of unique objects for this predicate
is_functional: boolWhether each subject maps to at most one object (functional property)
is_inverse_functional: boolWhether each object maps to at most one subject (inverse functional property)