pub enum DiffEntry {
Added(String),
Removed(String),
Modified {
before: String,
after: String,
},
}Expand description
A single change entry recorded in an OntologyDiff.
Variants
Added(String)
The symbol exists in b but not in a.
Removed(String)
The symbol exists in a but not in b.
Modified
The symbol exists in both but its definition changed.
Implementations
Sourceimpl DiffEntry
impl DiffEntry
Sourcepub fn is_addition(&self) -> bool
pub fn is_addition(&self) -> bool
Returns true if this is an DiffEntry::Added variant.
Sourcepub fn is_removal(&self) -> bool
pub fn is_removal(&self) -> bool
Returns true if this is a DiffEntry::Removed variant.
Sourcepub fn is_modification(&self) -> bool
pub fn is_modification(&self) -> bool
Returns true if this is a DiffEntry::Modified variant.