pub struct PropertyPathExpander { /* private fields */ }Expand description
Expands property path expressions against a triple store.
Implementations
Sourceimpl PropertyPathExpander
impl PropertyPathExpander
Sourcepub fn new(max_depth: usize) -> Self
pub fn new(max_depth: usize) -> Self
Create a new expander with the given maximum recursion depth.
Sourcepub fn expand(
&self,
start: &str,
path: &PropertyPath,
store: &TripleStore,
) -> Result<Vec<String>, PathError>
pub fn expand( &self, start: &str, path: &PropertyPath, store: &TripleStore, ) -> Result<Vec<String>, PathError>
Expand a property path from a starting node, returning all reachable objects.
Sourcepub fn expand_all(
&self,
path: &PropertyPath,
store: &TripleStore,
) -> Result<Vec<(String, String)>, PathError>
pub fn expand_all( &self, path: &PropertyPath, store: &TripleStore, ) -> Result<Vec<(String, String)>, PathError>
Expand a property path for ALL subjects, returning (subject, object) pairs.